@@ -1,5 +1,5 @@
-/* $Id: acpi.h 5948 2008-11-03 23:59:30Z timystery $ */
-/*  Copyright 2004-2007 Fabian Nowak (timystery@arcor.de)
+/* $Id$ */
+/*  Copyright 2004-2010 Fabian Nowak (timystery@arcor.de)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #define ACPI_FILE_BATTERY_INFO  "info"
 #define ACPI_FILE_FAN           "state"
 
-#define ACPI_INFO               "info_"
+#define ACPI_INFO               "info"
 
 /* Gtk/Glib includes */
 #include <glib.h>
