@@ -86,14 +86,23 @@ int
 read_thermal_zone (t_chip *chip)
 {
     DIR *d;
-    FILE *file;
-    char *zone, *filename;
+    FILE *file; 
+    char *filename;
     struct dirent *de;
     t_chipfeature *chipfeature;
+#ifdef HAVE_SYSFS_ACPI
+    char buf[1024];
+#else
+    char *zone;
+#endif
 
     TRACE ("enters read_thermal_zone");
 
+#ifdef HAVE_SYSFS_ACPI
+    if ((chdir ("/sys/class/") == 0) && (chdir ("thermal/") == 0))
+#else
     if ((chdir (ACPI_PATH) == 0) && (chdir (ACPI_DIR_THERMAL) == 0))
+#endif
     {
         d = opendir (".");
         if (!d) {
@@ -107,13 +116,17 @@ read_thermal_zone (t_chip *chip)
             if (strncmp(de->d_name, ".", 1)==0)
                 continue;
 
+#ifdef HAVE_SYSFS_ACPI
+            filename = g_strdup_printf ("/sys/class/thermal/%s/temp", de->d_name);
+#else
             filename = g_strdup_printf ("%s/%s/%s/%s", ACPI_PATH,
                                         ACPI_DIR_THERMAL, de->d_name,
                                         ACPI_FILE_THERMAL);
+#endif
             file = fopen (filename, "r");
             if (file)
             {
-                //printf ("parsing temperature file...\n");
+                printf ("parsing temperature file \"%s\"...\n", filename);
                 /* if (acpi_ignore_directory_entry (de))
                     continue; */
 
@@ -126,9 +139,19 @@ read_thermal_zone (t_chip *chip)
                 chipfeature->formatted_value = NULL; /*  Gonna refresh it in
                                                         sensors_get_wrapper or some
                                                         other functions */
+
+#ifdef HAVE_SYSFS_ACPI
+                if (fgets (buf, 1024, file)!=NULL)
+                {
+                    cut_newline (buf);
+                    chipfeature->raw_value = strtod (buf, NULL) / 1000.0;
+                    DBG ("Raw-Value=%f\n", chipfeature->raw_value);
+                }
+#else
                 zone = g_strdup_printf ("%s/%s", ACPI_DIR_THERMAL, de->d_name);
                 chipfeature->raw_value = get_acpi_zone_value (zone, ACPI_FILE_THERMAL);
                 g_free (zone);
+#endif
 
                 chipfeature->valid = TRUE;
                 chipfeature->min_value = 20.0;
@@ -289,8 +312,8 @@ int read_battery_zone (t_chip *chip)
 #endif
                 DBG ("filename=%s\n", filename);
                 file = fopen (filename, "r");
+                chipfeature = g_new0 (t_chipfeature, 1);
                 if (file) {
-                    chipfeature = g_new0 (t_chipfeature, 1);
                     chipfeature->address = chip->chip_features->len;
                     chipfeature->devicename = g_strdup (de->d_name);
 
@@ -367,6 +390,10 @@ int read_battery_zone (t_chip *chip)
                     continue; /* because, what would we want to do with only
                                 a maxval and no real value inside? */
                 }
+                /*
+                 * if no files found at all
+                 * g_free(chipfeature);
+                 */
 
                 g_free (filename);
 
@@ -518,6 +545,7 @@ int read_fan_zone (t_chip *chip)
 int initialize_ACPI (GPtrArray *chips)
 {
     t_chip *chip;
+    sensors_chip_name *ptr_chipname_tmp;
 
     TRACE ("enters initialize_ACPI");
 
@@ -529,8 +557,11 @@ int initialize_ACPI (GPtrArray *chips)
 
     chip->type = ACPI;
 
-    chip->chip_name = (const sensors_chip_name *)
-                            ( g_strdup(_("ACPI")), 0, 0, g_strdup(_("ACPI")) );
+    ptr_chipname_tmp = g_new0 (sensors_chip_name, 1);
+    ptr_chipname_tmp->prefix = g_strdup(_("ACPI"));
+    ptr_chipname_tmp->path = g_strdup(_("ACPI"));
+    
+    chip->chip_name = (const sensors_chip_name *) ptr_chipname_tmp;
 
     chip->chip_features = g_ptr_array_new ();
 
@@ -560,6 +591,11 @@ refresh_acpi (gpointer chip_feature, gpointer data)
 {
     char *file, *zone, *state;
     t_chipfeature *cf;
+    
+#ifdef HAVE_SYSFS_ACPI
+    FILE *f = NULL;
+    char buf[1024];
+#endif
 
     TRACE ("enters refresh_acpi");
 
@@ -569,8 +605,22 @@ refresh_acpi (gpointer chip_feature, gpointer data)
 
     switch (cf->class) {
         case TEMPERATURE:
+#ifdef HAVE_SYSFS_ACPI
+            zone = g_strdup_printf ("/sys/class/thermal_zone/%s/temp", cf->devicename);
+            f = fopen(zone, "r");
+            if (f != NULL)
+            {
+              if (fgets (buf, 1024, f))
+              {
+                cut_newline(buf);
+                cf->raw_value = strtod(buf, NULL) / 1000.0;
+              }
+              fclose (f);              
+            }
+#else
             zone = g_strdup_printf ("%s/%s", ACPI_DIR_THERMAL, cf->devicename);
             cf->raw_value = get_acpi_zone_value (zone, ACPI_FILE_THERMAL);
+#endif
             g_free (zone);
             /* g_free (cf->formatted_value);
             cf->formatted_value = g_strdup_printf (_("%+5.1f °C"), cf->raw_value); */
@@ -722,4 +772,3 @@ get_acpi_value (char *filename)
     /* Have read the data */
     return g_strdup (p);
 }
-
