@@ -126,6 +126,8 @@ sensors_write_config (XfcePanelPlugin *plugin, t_sensors *sensors)
 
     xfce_rc_write_bool_entry (rc, "Suppress_Hddtemp_Message", sensors->suppressmessage);
 
+    xfce_rc_write_bool_entry (rc, "Suppress_Tooltip", sensors->suppresstooltip);
+
   xfce_rc_write_int_entry (rc, "Preferred_Width", sensors->preferred_width);
   xfce_rc_write_int_entry (rc, "Preferred_Height", sensors->preferred_height);
 
@@ -239,6 +241,9 @@ sensors_read_general_config (XfceRc *rc, t_sensors *sensors)
 
         if (!sensors->suppressmessage)
             sensors->suppressmessage = xfce_rc_read_bool_entry (rc, "Suppress_Hddtemp_Message", FALSE);
+
+        if (!sensors->suppresstooltip)
+            sensors->suppresstooltip = xfce_rc_read_bool_entry (rc, "Suppress_Tooltip", FALSE);
             
         sensors->preferred_width = xfce_rc_read_int_entry (rc, "Preferred_Width", 400);
         sensors->preferred_height = xfce_rc_read_int_entry (rc, "Preferred_Height", 400);
@@ -327,18 +332,22 @@ sensors_read_config (XfcePanelPlugin *plugin, t_sensors *sensors)
             /* assert that file does not contain more information
               than does exist on system */
               /* ??? At least, it works. */
+              //DBG("number of chip from file: %d, number of expected or known chips: %d.\n", num_sensorchip, sensors->num_sensorchips);
             g_return_if_fail (num_sensorchip < sensors->num_sensorchips);
+            //DBG ("Success.\n");
 
             /* now featuring enhanced string comparison */
             //g_assert (chip!=NULL);
             k = 0;
             do {
               chip = (t_chip *) g_ptr_array_index (sensors->chips, k++);
-              if (chip==NULL)
+              if (chip==NULL || k==sensors->num_sensorchips)
                   break;
+              //DBG("k=%d, chip=%p, name=.\n", k, chip);
               }
-            while ( strcmp(chip->sensorId, sensorName) != 0 );
-            if ( chip!=NULL && strcmp(chip->sensorId, sensorName)==0 ) {
+            while (chip!=NULL && sensorName != NULL && strcmp(chip->sensorId, sensorName) != 0 );
+            //DBG("Found a chip.\n");
+            if ( chip!=NULL && sensorName != NULL && strcmp(chip->sensorId, sensorName)==0 ) {
 
                 for (j=0; j<chip->num_features; j++) {
                     chipfeature = (t_chipfeature *) g_ptr_array_index (
@@ -410,13 +419,14 @@ sensors_read_config (XfcePanelPlugin *plugin, t_sensors *sensors)
 
                 } /* end for features */
 
-            } /* end if */
+            } /* end if chip && strcmp */
 
-            g_free (sensorName);
+            if (sensorName != NULL)
+              g_free (sensorName);
 
-        } /* end if */
+        } /* end if xfce_rc_has_group (rc, rc_chip) */
 
-    } /* end for */
+    } /* end for num_sensorchips */
 
     xfce_rc_close (rc);
 
