@@ -54,6 +54,20 @@
 /* Local includes */
 #include "sensors-plugin.h"
 
+static void
+remove_gsource (guint gsource_id)
+{
+    GSource *ptr_gsource;
+    if (gsource_id != 0) 
+    {
+        ptr_gsource = g_main_context_find_source_by_id (NULL, gsource_id);
+        if (ptr_gsource != NULL) 
+        {
+            g_source_destroy (ptr_gsource);
+            gsource_id = 0;
+        }
+    }
+}
 
 static void
 sensors_set_bar_size (GtkWidget *bar, int size, int orientation)
@@ -147,7 +161,7 @@ sensors_remove_graphical_panel (t_sensors *sensors)
             if (chipfeature->show == TRUE) {
                 panel = (t_barpanel*) sensors->panels[chipNum][feature];
 
-        if (sensors->show_labels == TRUE) /* FN: FIXME; this value is already updated! */
+                if (sensors->show_labels == TRUE) /* FN: FIXME; this value is already updated! */
                     gtk_widget_destroy (panel->label);
 
                 gtk_widget_destroy (panel->progressbar);
@@ -284,8 +298,7 @@ sensors_add_graphical_display (t_sensors *sensors)
 
     TRACE ("enters sensors_add_graphical_display");
 
-    text = g_strdup (_("<span foreground=\"#000000\">"
-                                     "<b>Sensors</b></span>"));
+    text = g_strdup (_("<span><b>Sensors</b></span>"));
     gtk_label_set_markup (GTK_LABEL(sensors->panel_label_text), text);
     g_free (text);
 
@@ -381,8 +394,7 @@ sensors_add_tacho_display (t_sensors *sensors)
 
     TRACE ("enters sensors_add_tacho_display");
 
-    text = g_strdup (_("<span foreground=\"#000000\">"
-                                     "<b>Sensors</b></span>"));
+    text = g_strdup (_("<span><b>Sensors</b></span>"));
     gtk_label_set_markup (GTK_LABEL(sensors->panel_label_text), text);
     g_free (text);
 
@@ -622,9 +634,11 @@ sensors_set_text_panel_label (t_sensors *sensors, gint numCols, gint itemsToDisp
             
             if (chipfeature->show == TRUE) {
                 if(sensors->show_labels==TRUE) {
-                  tmpstring = g_strconcat (myLabelText, "<span size=\"", sensors->font_size, "\">",chipfeature->name, ":</span> ", NULL);
+                  tmpstring = g_strconcat (myLabelText, "<span size=\"", sensors->font_size, "\">",chipfeature->name, NULL);
+                  
                   g_free(myLabelText);
-                  myLabelText = tmpstring;
+                  myLabelText = g_strconcat (tmpstring, ":</span> ", NULL);
+                  g_free(tmpstring);
                 }
                 
                 if (sensors->show_units) {
@@ -633,18 +647,23 @@ sensors_set_text_panel_label (t_sensors *sensors, gint numCols, gint itemsToDisp
                                             chipfeature->color, "\" size=\"",
                                             sensors->font_size, "\">",
                                             chipfeature->formatted_value,
-                                            "</span>", NULL);
+                                            NULL);
+                                              
+                  myLabelText = g_strconcat (tmpstring,
+                                              "</span>", NULL);
+
+                  g_free (tmpstring);
                 }
                 else {
                     tmpstring = g_strdup_printf("%s<span foreground=\"%s\" size=\"%s\">%.1f</span>", myLabelText,
                             chipfeature->color, sensors->font_size,
                             chipfeature->raw_value);
                     //myLabelText = g_strconcat (myLabelText, tmpstring, NULL);
+                    g_free(myLabelText);
+                    myLabelText = tmpstring;
                 }
-
-                g_free (myLabelText);
-
-                myLabelText = tmpstring;
+                
+                  
 
                 if (sensors->orientation == GTK_ORIENTATION_VERTICAL) {
                     if (itemsToDisplay > 1) {
@@ -711,15 +730,15 @@ count_number_checked_sensor_features (t_sensors *sensors)
         chip = (t_chip *) g_ptr_array_index (sensors->chips, chipNum);
         g_assert (chip!=NULL);
 
-        for (feature=0; feature<chip->num_features; /* none */ ) {
+        for (feature=0; feature<chip->num_features; feature++) {
             chipfeature = g_ptr_array_index (chip->chip_features, feature);
             g_assert (chipfeature!=NULL);
 
-            if (chipfeature->show == TRUE)
+            if (chipfeature->valid == TRUE && chipfeature->show == TRUE)
                 itemsToDisplay++;
 
-            if (chipfeature->valid == TRUE)
-                feature++;
+            //if (chipfeature->valid == TRUE)
+                //feature++;
         }
     }
 
@@ -799,12 +818,12 @@ sensors_create_tooltip (gpointer data)
 
                     if (first == TRUE) {
                         g_free (myToolTipText);
-                        myToolTipText = g_strdup (chip->sensorId);
+                        myToolTipText = g_strconcat ("<b>", chip->sensorId, "</b>", NULL);
                         first = FALSE;
                     }
                     else {
-                        myToolTipText2 = g_strconcat (myToolTipText, " \n",
-                                                     chip->sensorId, NULL);
+                        myToolTipText2 = g_strconcat (myToolTipText, " \n<b>",
+                                                     chip->sensorId, "</b>", NULL);
                         TRACE ("freeing myToolTipText");
                         g_free (myToolTipText);
                         myToolTipText = myToolTipText2;
@@ -847,9 +866,11 @@ sensors_create_tooltip (gpointer data)
         }
     }
 
-    gtk_widget_set_tooltip_text (GTK_WIDGET(sensors->eventbox), myToolTipText);
+    gtk_widget_set_tooltip_markup (GTK_WIDGET(sensors->eventbox), myToolTipText);
     DBG("tooltip text: %s.\n", myToolTipText);
     
+    gtk_widget_set_has_tooltip(GTK_WIDGET(sensors->eventbox), !sensors->suppresstooltip);
+    
     TRACE ("freeing myToolTipText");
     g_free (myToolTipText);
 
@@ -871,8 +892,6 @@ sensors_show_panel (gpointer data)
 
     sensors = (t_sensors *) data;
 
-    sensors_create_tooltip ((gpointer) sensors);
-
     switch (sensors->display_values_type)
     {
       case DISPLAY_TACHO: 
@@ -884,6 +903,9 @@ sensors_show_panel (gpointer data)
       default:
         result = sensors_show_text_display (sensors);
     }
+    
+    sensors_create_tooltip ((gpointer) sensors);
+    
     TRACE ("leaves sensors_show_panel\n");
     return result;
 }
@@ -974,8 +996,7 @@ create_panel_widget (t_sensors * sensors)
     gtk_misc_set_padding (GTK_MISC(sensors->panel_label_text), INNER_BORDER, 0);
     gtk_misc_set_alignment(GTK_MISC(sensors->panel_label_text), 0.0, 0.5);
 
-    myLabelText = g_strdup (_("<span foreground=\"#000000\"><b>Sensors"
-                                    "</b></span>"));
+    myLabelText = g_strdup (_("<span><b>Sensors</b></span>"));
     gtk_label_set_markup(GTK_LABEL(sensors->panel_label_text), myLabelText);
     gtk_widget_show (sensors->panel_label_text);
     g_free(myLabelText);
@@ -1022,7 +1043,7 @@ execute_command (GtkWidget *widget, GdkEventButton *event, gpointer data)
     }
     else {
         TRACE ("leaves execute_command with FALSE");
-        return FALSE;
+        return FALSE; // with FALSE, the event will not have been accepted by the handler and will be propagated further
     }
 }
 
@@ -1038,11 +1059,10 @@ sensors_free (XfcePanelPlugin *plugin, t_sensors *sensors)
     sensor_interface_cleanup();
 
     /* remove timeout functions */
-    if (sensors->timeout_id)
-        g_source_remove (sensors->timeout_id);
+    remove_gsource (sensors->timeout_id);
 
     /* double-click improvement */
-    g_source_remove (sensors->doubleclick_id);
+    remove_gsource (sensors->doubleclick_id);
 
     /* free structures and arrays */
     g_ptr_array_foreach (sensors->chips, free_chip, NULL);
@@ -1190,6 +1210,21 @@ display_style_changed_bars (GtkWidget *widget, t_sensors_dialog *sd)
     TRACE ("leaves display_style_changed_bars");
 }
 
+
+
+static void
+suppresstooltip_changed (GtkWidget *widget, t_sensors_dialog* sd)
+{
+    TRACE ("enters suppresstooltip_changed");
+
+    sd->sensors->suppresstooltip = ! sd->sensors->suppresstooltip;
+    
+    gtk_widget_set_has_tooltip(sd->sensors->eventbox, !sd->sensors->suppresstooltip);
+
+    TRACE ("leaves suppresstooltip_changed");
+}
+
+
 static void
 display_style_changed_tacho (GtkWidget *widget, t_sensors_dialog *sd)
 {
@@ -1212,6 +1247,9 @@ display_style_changed_tacho (GtkWidget *widget, t_sensors_dialog *sd)
     sd->sensors->display_values_type = DISPLAY_TACHO;
     //gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON(widget) );
 
+    if (!sd->sensors->suppresstooltip)
+      suppresstooltip_changed (widget, sd);
+    
     sensors_show_panel ((gpointer) sd->sensors);
 
     TRACE ("leaves display_style_changed_tacho");
@@ -1307,7 +1345,7 @@ adjustment_value_changed (GtkWidget *widget, t_sensors_dialog* sd)
         (gint) gtk_adjustment_get_value ( GTK_ADJUSTMENT (widget) );
 
     /* stop the timeout functions ... */
-    g_source_remove (sd->sensors->timeout_id);
+    remove_gsource (sd->sensors->timeout_id);
     /* ... and start them again */
     sd->sensors->timeout_id  = g_timeout_add (
         sd->sensors->sensors_refresh_time * 1000,
@@ -1980,6 +2018,24 @@ add_suppressmessage_box (GtkWidget * vbox, t_sensors_dialog * sd)
     TRACE ("leaves add_suppressmessage_box");
 }
 
+static void
+add_suppresstooltips_box (GtkWidget * vbox, t_sensors_dialog * sd)
+{
+    TRACE ("enters add_suppresstooltips_box");
+
+    sd->suppresstooltip_checkbox  = gtk_check_button_new_with_mnemonic(_("Suppress tooltip"));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sd->suppresstooltip_checkbox), sd->sensors->suppresstooltip);
+
+    gtk_widget_show (sd->suppresstooltip_checkbox);
+
+    gtk_box_pack_start (GTK_BOX (vbox), sd->suppresstooltip_checkbox, FALSE, TRUE, 0);
+
+    g_signal_connect   (G_OBJECT (sd->suppresstooltip_checkbox), "toggled",
+                        G_CALLBACK (suppresstooltip_changed), sd );
+
+    TRACE ("leaves add_suppresstooltips_box");
+}
+
 
 /* double-click improvement */
 static void
@@ -2080,8 +2136,10 @@ add_miscellaneous_frame (GtkWidget * notebook, t_sensors_dialog * sd)
 
     add_suppressmessage_box(_vbox, sd);
 
+    add_suppresstooltips_box(_vbox, sd);
+    
     add_command_box (_vbox, sd);
-
+    
     TRACE ("leaves add_miscellaneous_frame");
 }
 
@@ -2212,7 +2270,6 @@ add_event_box (t_sensors *sensors)
     /* create eventbox to catch events on widget */
     sensors->eventbox = gtk_event_box_new ();
     gtk_widget_set_name (sensors->eventbox, "xfce_sensors");
-    gtk_widget_show (sensors->eventbox);
 
     /* double-click improvement */
     sensors->doubleclick_id = g_signal_connect (G_OBJECT(sensors->eventbox),
@@ -2244,7 +2301,7 @@ create_sensors_control (XfcePanelPlugin *plugin)
     add_event_box (sensors);
 
     /* Add tooltip to show extended current sensors status */
-    sensors_create_tooltip ((gpointer) sensors);
+    //sensors_create_tooltip ((gpointer) sensors);
 
     /* fill panel widget with boxes, strings, values, ... */
     create_panel_widget (sensors);
@@ -2253,6 +2310,7 @@ create_sensors_control (XfcePanelPlugin *plugin)
     gtk_container_add (GTK_CONTAINER (sensors->eventbox),
                        sensors->widget_sensors);
 
+    
     /* sensors_set_size (control, settings.size); */
 
     TRACE ("leaves create_sensors_control");
@@ -2307,9 +2365,10 @@ sensors_plugin_construct (XfcePanelPlugin *plugin)
     gtk_container_add (GTK_CONTAINER(plugin), sensors->eventbox);
 
     xfce_panel_plugin_add_action_widget (plugin, sensors->eventbox);
-
+    
+    gtk_widget_show (sensors->eventbox);
+    
     TRACE ("leaves sensors_plugin_construct");
 }
 
 XFCE_PANEL_PLUGIN_REGISTER_EXTERNAL (sensors_plugin_construct);
-
