@@ -37,6 +37,7 @@
 
 /* Local includes */
 #include "actions.h"
+#include "interface.h"
 
 /* foward declaration */
 gboolean
@@ -119,7 +120,7 @@ gtk_widget_unparent_ext (GtkWidget *widget, gpointer data)
 void
 refresh_tacho_view (t_sensors_dialog *sd)
 {
-  GtkTreeModel *  model;
+  //GtkTreeModel *  model;
   int i, index_feature, row=0, col=0;
   t_sensors *sensors;
   t_chipfeature *chipfeature;
@@ -127,6 +128,7 @@ refresh_tacho_view (t_sensors_dialog *sd)
   GtkWidget *table; //, *widget;
   //GList *list;
   gdouble d;
+  gchar *myToolTipText;
   
   TRACE ("enters refresh_tacho_view");
   
@@ -134,7 +136,7 @@ refresh_tacho_view (t_sensors_dialog *sd)
   
   sensors = sd->sensors;
   
-  model = gtk_tree_view_get_model(GTK_TREE_VIEW(sd->myTreeView));
+  //model = gtk_tree_view_get_model(GTK_TREE_VIEW(sd->myTreeView));
   
   table = sensors->widget_sensors;
   
@@ -199,6 +201,11 @@ refresh_tacho_view (t_sensors_dialog *sd)
                 //gtk_cpu_paint(sensors->tachos [i][index_feature]);
                 //gtk_cpu_expose(sensors->tachos [i][index_feature], NULL);
                 
+    /* #if GTK_VERSION < 2.11 */
+    myToolTipText = g_strdup(_("You can change a feature's properties such as name, colours, min/max value by double-clicking the entry, editing the content, and pressing \"Return\" or selecting a different field."));
+    gtk_tooltips_set_tip (tooltips, GTK_WIDGET(sensors->tachos [i][index_feature]),
+                          myToolTipText, NULL);
+                
                 if (col>=3) {
                     row++;
                     col = 0;
